@@ -80,81 +80,83 @@ print("FAST_PYTHON_PREFIX:", os.environ.get('FAST_PYTHON_PREFIX'))
 print(sys.prefix)
 print(os.path.normpath(sys.prefix))
 sys.prefix = expected_python_prefix
+print(sys.prefix)
+print(os.path.normpath(sys.prefix))
 print("actual_python_prefix:", os.path.realpath(os.path.normpath(sys.prefix)))
 print("FAST_PYTHON_VERSION:", os.environ.get('FAST_PYTHON_VERSION'))
 print("actual_python_version:", actual_python_version)
 print("666")
 print(python_prefix_matches, python_version_matches)
 
-config_file = os.environ.get('FAST_CONFIG_FILE', None)
-environment = os.environ.get('FAST_ENVIRONMENT', None)
+# config_file = os.environ.get('FAST_CONFIG_FILE', None)
+# environment = os.environ.get('FAST_ENVIRONMENT', None)
+#
+# log_message('initialize_agent = %r', bool(config_file))
+# print("777")
+# print("config_file_", config_file)
+# if config_file:
+#     do_insert_path = root_directory not in sys.path
+#     if do_insert_path:
+#         sys.path.insert(0, root_directory)
+#
+#     import fast_tracker.config
+#
+#     log_message('agent_version = %r', fast_tracker.version)
+#
+#     if do_insert_path:
+#         try:
+#             del sys.path[sys.path.index(root_directory)]
+#         except Exception:
+#             pass
+#
+# # 探针初始化
+# print("121212")
+# try:
+#     print("11111111")
+#     from fast_tracker import agent, config
+#
+#     print("888")
+#     # config.init(collector="127.0.0.1:8111", service="as you wish")
+#     config.init(collector="fluent-bit:5140", service="as you wish")
+#     print("999")
+#     agent.start()
+#     print("101010")
+# except BaseException as e:
+#     print("发生错误了，错误信息是", e)
+if python_prefix_matches and python_version_matches:
 
-log_message('initialize_agent = %r', bool(config_file))
-print("777")
-print("config_file_", config_file)
-if config_file:
-    do_insert_path = root_directory not in sys.path
-    if do_insert_path:
-        sys.path.insert(0, root_directory)
+    config_file = os.environ.get('FAST_CONFIG_FILE', None)
+    environment = os.environ.get('FAST_ENVIRONMENT', None)
 
-    import fast_tracker.config
+    log_message('initialize_agent = %r', bool(config_file))
+    print("777")
+    print("config_file_", config_file)
+    if config_file:
+        do_insert_path = root_directory not in sys.path
+        if do_insert_path:
+            sys.path.insert(0, root_directory)
 
-    log_message('agent_version = %r', fast_tracker.version)
+        import fast_tracker.config
 
-    if do_insert_path:
-        try:
-            del sys.path[sys.path.index(root_directory)]
-        except Exception:
-            pass
+        log_message('agent_version = %r', fast_tracker.version)
 
-# 探针初始化
-print("121212")
-try:
-    print("11111111")
-    from fast_tracker import agent, config
+        if do_insert_path:
+            try:
+                del sys.path[sys.path.index(root_directory)]
+            except Exception:
+                pass
 
-    print("888")
-    # config.init(collector="127.0.0.1:8111", service="as you wish")
-    config.init(collector="fluent-bit:5140", service="as you wish")
-    print("999")
-    agent.start()
-    print("101010")
-except BaseException as e:
-    print("发生错误了，错误信息是", e)
-# if python_prefix_matches and python_version_matches:
-#
-#     config_file = os.environ.get('FAST_CONFIG_FILE', None)
-#     environment = os.environ.get('FAST_ENVIRONMENT', None)
-#
-#     log_message('initialize_agent = %r', bool(config_file))
-#     print("777")
-#     print("config_file_", config_file)
-#     if config_file:
-#         do_insert_path = root_directory not in sys.path
-#         if do_insert_path:
-#             sys.path.insert(0, root_directory)
-#
-#         import fast_tracker.config
-#
-#         log_message('agent_version = %r', fast_tracker.version)
-#
-#         if do_insert_path:
-#             try:
-#                 del sys.path[sys.path.index(root_directory)]
-#             except Exception:
-#                 pass
-#
-#     # 探针初始化
-#     print("121212")
-#     try:
-#         print("11111111")
-#         from fast_tracker import agent, config
-#
-#         print("888")
-#         # config.init(collector="127.0.0.1:8111", service="as you wish")
-#         config.init(collector="fluent-bit:5140", service="as you wish")
-#         print("999")
-#         agent.start()
-#         print("101010")
-#     except BaseException as e:
-#         print("发生错误了，错误信息是", e)
+    # 探针初始化
+    print("121212")
+    try:
+        print("11111111")
+        from fast_tracker import agent, config
+
+        print("888")
+        # config.init(collector="127.0.0.1:8111", service="as you wish")
+        config.init(collector="fluent-bit:5140", service="as you wish")
+        print("999")
+        agent.start()
+        print("101010")
+    except BaseException as e:
+        print("发生错误了，错误信息是", e)
